public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "Michael Kubacki" <mikuback@linux.microsoft.com>
To: devel@edk2.groups.io
Cc: Hao A Wu <hao.a.wu@intel.com>,
	Michael D Kinney <michael.d.kinney@intel.com>
Subject: [PATCH v1 1/3] SourceLevelDebugPkg: Fix spelling errors
Date: Tue,  4 Oct 2022 11:18:56 -0400	[thread overview]
Message-ID: <20221004151858.870-2-mikuback@linux.microsoft.com> (raw)
In-Reply-To: <20221004151858.870-1-mikuback@linux.microsoft.com>

From: Michael Kubacki <michael.kubacki@microsoft.com>

REF:https://bugzilla.tianocore.org/show_bug.cgi?id=4091

Fixes spelling errors in the package so the SpellCheck CI plugin can
be enabled.

Cc: Hao A Wu <hao.a.wu@intel.com>
Cc: Michael D Kinney <michael.d.kinney@intel.com>
Signed-off-by: Michael Kubacki <michael.kubacki@microsoft.com>
---
 SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.c                          |  8 +++----
 SourceLevelDebugPkg/Library/DebugAgent/DxeDebugAgent/SerialIo.c                               | 22 ++++++++++----------
 SourceLevelDebugPkg/Library/DebugCommunicationLibSerialPort/DebugCommunicationLibSerialPort.c |  2 +-
 SourceLevelDebugPkg/Library/DebugCommunicationLibUsb/DebugCommunicationLibUsb.c               |  2 +-
 SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/Ia32/IntHandlerFuncs.c                  |  2 +-
 SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/X64/IntHandlerFuncs.c                   |  2 +-
 SourceLevelDebugPkg/Include/Library/DebugCommunicationLib.h                                   |  2 +-
 SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.h                          |  2 +-
 SourceLevelDebugPkg/Library/DebugCommunicationLibUsb3/DebugCommunicationLibUsb3Internal.h     |  2 +-
 SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/PeCoffExtraActionLib.h                  |  2 +-
 10 files changed, 23 insertions(+), 23 deletions(-)

diff --git a/SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.c b/SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.c
index a1e61a6ef90e..b553a2a9aa0c 100644
--- a/SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.c
+++ b/SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.c
@@ -1,5 +1,5 @@
 /** @file
-  Commond Debug Agent library implementation. It mainly includes
+  Common Debug Agent library implementation. It mainly includes
   the first C function called by exception/interrupt handlers,
   read/write debug packet to communication with HOST based on transfer
   protocol.
@@ -608,7 +608,7 @@ DebugAgentDataMsgPrint (
 }
 
 /**
-  Read remaing debug packet except for the start symbol
+  Read remaining debug packet except for the start symbol
 
   @param[in]      Handle        Pointer to Debug Port handle.
   @param[in, out] DebugHeader   Debug header buffer including start symbol.
@@ -616,7 +616,7 @@ DebugAgentDataMsgPrint (
   @retval EFI_SUCCESS        Read the symbol in BreakSymbol.
   @retval EFI_CRC_ERROR      CRC check fail.
   @retval EFI_TIMEOUT        Timeout occurs when reading debug packet.
-  @retval EFI_DEVICE_ERROR   Receive the old or responsed packet.
+  @retval EFI_DEVICE_ERROR   Receive the old or response packet.
 
 **/
 EFI_STATUS
@@ -651,7 +651,7 @@ ReadRemainingBreakPacket (
   if (IS_REQUEST (DebugHeader)) {
     if (DebugHeader->SequenceNo == (UINT8)(Mailbox->HostSequenceNo + 1)) {
       //
-      // Only updagte HostSequenceNo for new command packet
+      // Only update HostSequenceNo for new command packet
       //
       UpdateMailboxContent (Mailbox, DEBUG_MAILBOX_HOST_SEQUENCE_NO_INDEX, DebugHeader->SequenceNo);
       return EFI_SUCCESS;
diff --git a/SourceLevelDebugPkg/Library/DebugCommunicationLibSerialPort/DebugCommunicationLibSerialPort.c b/SourceLevelDebugPkg/Library/DebugCommunicationLibSerialPort/DebugCommunicationLibSerialPort.c
index 34c269e6b527..9953904725ac 100644
--- a/SourceLevelDebugPkg/Library/DebugCommunicationLibSerialPort/DebugCommunicationLibSerialPort.c
+++ b/SourceLevelDebugPkg/Library/DebugCommunicationLibSerialPort/DebugCommunicationLibSerialPort.c
@@ -70,7 +70,7 @@ DebugPortInitialize (
 }
 
 /**
-  Read data from debug device and save the datas in buffer.
+  Read data from debug device and save the data in a buffer.
 
   Reads NumberOfBytes data bytes from a debug device into the buffer
   specified by Buffer. The number of bytes actually read is returned.
diff --git a/SourceLevelDebugPkg/Library/DebugCommunicationLibUsb/DebugCommunicationLibUsb.c b/SourceLevelDebugPkg/Library/DebugCommunicationLibUsb/DebugCommunicationLibUsb.c
index 479757f5bae2..da55f3e69ef0 100644
--- a/SourceLevelDebugPkg/Library/DebugCommunicationLibUsb/DebugCommunicationLibUsb.c
+++ b/SourceLevelDebugPkg/Library/DebugCommunicationLibUsb/DebugCommunicationLibUsb.c
@@ -768,7 +768,7 @@ InitializeUsbDebugHardware (
 }
 
 /**
-  Read data from debug device and save the datas in buffer.
+  Read data from debug device and save the data in a buffer.
 
   Reads NumberOfBytes data bytes from a debug device into the buffer
   specified by Buffer. The number of bytes actually read is returned.
diff --git a/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/Ia32/IntHandlerFuncs.c b/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/Ia32/IntHandlerFuncs.c
index 600bde10d656..3e6db0db8679 100644
--- a/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/Ia32/IntHandlerFuncs.c
+++ b/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/Ia32/IntHandlerFuncs.c
@@ -15,7 +15,7 @@
   @param[in]  InterruptType      Interrupt type.
 
   @retval  TRUE     IDT entries were setup by Debug Agent.
-  @retval  FALSE    IDT entries were not setuo by Debug Agent.
+  @retval  FALSE    IDT entries were not setup by Debug Agent.
 
 **/
 BOOLEAN
diff --git a/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/X64/IntHandlerFuncs.c b/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/X64/IntHandlerFuncs.c
index 952285a8eac0..1baa88206b06 100644
--- a/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/X64/IntHandlerFuncs.c
+++ b/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/X64/IntHandlerFuncs.c
@@ -15,7 +15,7 @@
   @param[in]  InterruptType      Interrupt type.
 
   @retval  TRUE     IDT entries were setup by Debug Agent.
-  @retval  FALSE    IDT entries were not setuo by Debug Agent.
+  @retval  FALSE    IDT entries were not setup by Debug Agent.
 
 **/
 BOOLEAN
diff --git a/SourceLevelDebugPkg/Include/Library/DebugCommunicationLib.h b/SourceLevelDebugPkg/Include/Library/DebugCommunicationLib.h
index ad7bccda285c..ebb2168632da 100644
--- a/SourceLevelDebugPkg/Include/Library/DebugCommunicationLib.h
+++ b/SourceLevelDebugPkg/Include/Library/DebugCommunicationLib.h
@@ -71,7 +71,7 @@ DebugPortInitialize (
   );
 
 /**
-  Read data from debug device and save the datas in buffer.
+  Read data from debug device and save the data in a buffer.
 
   Reads NumberOfBytes data bytes from a debug device into the buffer
   specified by Buffer. The number of bytes actually read is returned.
diff --git a/SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.h b/SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.h
index a0ede308efee..4c72f8f3a90c 100644
--- a/SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.h
+++ b/SourceLevelDebugPkg/Library/DebugAgent/DebugAgentCommon/DebugAgent.h
@@ -452,7 +452,7 @@ DebugAgentDataMsgPrint (
   );
 
 /**
-  Read remaing debug packet except for the start symbol
+  Read remaining debug packet except for the start symbol
 
   @param[in]      Handle        Pointer to Debug Port handle.
   @param[in, out] DebugHeader   Debug header buffer including start symbol.
diff --git a/SourceLevelDebugPkg/Library/DebugCommunicationLibUsb3/DebugCommunicationLibUsb3Internal.h b/SourceLevelDebugPkg/Library/DebugCommunicationLibUsb3/DebugCommunicationLibUsb3Internal.h
index c73233ea49b0..cc5f294f334d 100644
--- a/SourceLevelDebugPkg/Library/DebugCommunicationLibUsb3/DebugCommunicationLibUsb3Internal.h
+++ b/SourceLevelDebugPkg/Library/DebugCommunicationLibUsb3/DebugCommunicationLibUsb3Internal.h
@@ -586,7 +586,7 @@ XhcWriteDebugReg (
 /**
   Verifies if the bit positions specified by a mask are set in a register.
 
-  @param[in, out] Register    UNITN register
+  @param[in, out] Register    UINTN register
   @param[in]      BitMask     32-bit mask
 
   @return  BOOLEAN  - TRUE  if all bits specified by the mask are enabled.
diff --git a/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/PeCoffExtraActionLib.h b/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/PeCoffExtraActionLib.h
index 149186b226f4..f428af963231 100644
--- a/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/PeCoffExtraActionLib.h
+++ b/SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/PeCoffExtraActionLib.h
@@ -34,7 +34,7 @@ extern UINTN  AsmInterruptHandle;
   @param[in]  InterruptType      Interrupt type.
 
   @retval  TRUE     IDT entries were setup by Debug Agent.
-  @retval  FALSE    IDT entries were not setuo by Debug Agent.
+  @retval  FALSE    IDT entries were not setup by Debug Agent.
 
 **/
 BOOLEAN
diff --git a/SourceLevelDebugPkg/Library/DebugAgent/DxeDebugAgent/SerialIo.c b/SourceLevelDebugPkg/Library/DebugAgent/DxeDebugAgent/SerialIo.c
index 6661275cc343..97d30c802df4 100644
--- a/SourceLevelDebugPkg/Library/DebugAgent/DxeDebugAgent/SerialIo.c
+++ b/SourceLevelDebugPkg/Library/DebugAgent/DxeDebugAgent/SerialIo.c
@@ -213,10 +213,10 @@ SERIAL_IO_DEVICE_PATH  mSerialIoDevicePath = {
   }
 };
 
-#define DEBGU_SERIAL_IO_FIFO_DEPTH  10
+#define DEBUG_SERIAL_IO_FIFO_DEPTH  10
 //
 //  Data buffer for Terminal input character and Debug Symbols.
 //  The depth is DEBGU_SERIAL_IO_FIFO_DEPTH.
 //  Fields:
 //      First   UINT8: The index of the first data in array Data[].
 //      Last    UINT8: The index, which you can put a new data into array Data[].
@@ -227,7 +227,7 @@ typedef struct {
   UINT8    First;
   UINT8    Last;
   UINT8    Surplus;
-  UINT8    Data[DEBGU_SERIAL_IO_FIFO_DEPTH];
+  UINT8    Data[DEBUG_SERIAL_IO_FIFO_DEPTH];
 } DEBUG_SERIAL_FIFO;
 
 //
@@ -236,10 +236,10 @@ typedef struct {
 EFI_HANDLE         mSerialIoHandle        = NULL;
 UINTN              mLoopbackBuffer        = 0;
 DEBUG_SERIAL_FIFO  mSerialFifoForTerminal = {
-  0, 0, DEBGU_SERIAL_IO_FIFO_DEPTH, { 0 }
+  0, 0, DEBUG_SERIAL_IO_FIFO_DEPTH, { 0 }
 };
 DEBUG_SERIAL_FIFO  mSerialFifoForDebug = {
-  0, 0, DEBGU_SERIAL_IO_FIFO_DEPTH, { 0 }
+  0, 0, DEBUG_SERIAL_IO_FIFO_DEPTH, { 0 }
 };
 
 /**
@@ -251,11 +251,11 @@ DEBUG_SERIAL_FIFO  mSerialFifoForDebug = {
 
 **/
 BOOLEAN
-IsDebugTermianlFifoEmpty (
+IsDebugTerminalFifoEmpty (
   IN DEBUG_SERIAL_FIFO  *Fifo
   )
 {
-  if (Fifo->Surplus == DEBGU_SERIAL_IO_FIFO_DEPTH) {
+  if (Fifo->Surplus == DEBUG_SERIAL_IO_FIFO_DEPTH) {
     return TRUE;
   }
 
@@ -313,7 +313,7 @@ DebugTerminalFifoAdd (
   Fifo->Data[Fifo->Last] = Data;
   Fifo->Surplus--;
   Fifo->Last++;
-  if (Fifo->Last == DEBGU_SERIAL_IO_FIFO_DEPTH) {
+  if (Fifo->Last == DEBUG_SERIAL_IO_FIFO_DEPTH) {
     Fifo->Last = 0;
   }
 
@@ -339,7 +339,7 @@ DebugTerminalFifoRemove (
   //
   // if FIFO is empty, no data can remove
   //
-  if (IsDebugTermianlFifoEmpty (Fifo)) {
+  if (IsDebugTerminalFifoEmpty (Fifo)) {
     return EFI_OUT_OF_RESOURCES;
   }
 
@@ -349,7 +349,7 @@ DebugTerminalFifoRemove (
   *Data = Fifo->Data[Fifo->First];
   Fifo->Surplus++;
   Fifo->First++;
-  if (Fifo->First == DEBGU_SERIAL_IO_FIFO_DEPTH) {
+  if (Fifo->First == DEBUG_SERIAL_IO_FIFO_DEPTH) {
     Fifo->First = 0;
   }
 
@@ -532,7 +532,7 @@ SerialGetControl (
   // Check to see if the Terminal FIFO is empty and
   // check to see if the input buffer in the Debug Communication Library is empty
   //
-  if (!IsDebugTermianlFifoEmpty (&mSerialFifoForTerminal) || DebugPortPollBuffer (Handle)) {
+  if (!IsDebugTerminalFifoEmpty (&mSerialFifoForTerminal) || DebugPortPollBuffer (Handle)) {
     *Control &= ~EFI_SERIAL_INPUT_BUFFER_EMPTY;
   }
 
@@ -213,10 +213,10 @@ SERIAL_IO_DEVICE_PATH  mSerialIoDevicePath = {
 //
 //  Data buffer for Terminal input character and Debug Symbols.
-//  The depth is DEBGU_SERIAL_IO_FIFO_DEPTH.
+//  The depth is DEBUG_SERIAL_IO_FIFO_DEPTH.
 //  Fields:
 //      First   UINT8: The index of the first data in array Data[].
-- 
2.28.0.windows.1


  reply	other threads:[~2022-10-04 15:19 UTC|newest]

Thread overview: 7+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-10-04 15:18 [PATCH v1 0/3] SourceLevelDebugPkg: Enable CI Michael Kubacki
2022-10-04 15:18 ` Michael Kubacki [this message]
2022-10-04 15:18 ` [PATCH v1 2/3] SourceLevelDebugPkg: Add package CI YAML file Michael Kubacki
2022-10-04 15:18 ` [PATCH v1 3/3] .azurepipelines: Add SourceLevelDebugPkg to CI Michael Kubacki
2022-10-04 15:49 ` [PATCH v1 0/3] SourceLevelDebugPkg: Enable CI Michael D Kinney
2022-10-05  1:24 ` Wu, Hao A
2022-10-05  1:29   ` [edk2-devel] " Michael Kubacki

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20221004151858.870-2-mikuback@linux.microsoft.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox